@@ -39,6 +39,7 @@ import gconf
 from about_dialog import AccerciserAboutDialog
 from prefs_dialog import AccerciserPreferencesDialog
 from main_window import AccerciserMainWindow
+import ui_manager
 
 GLADE_FILENAME = os.path.join(sys.prefix, 'share', 'accerciser', 'glade', 
                               'accerciser.glade')
@@ -47,7 +48,7 @@ if not os.path.exists(GLADE_FILENAME):
   
 GCONF_GENERAL = '/apps/accerciser/general'
 
-class MainWindow(Tools):
+class Main(Tools):
   '''
   Class for the main accerciser window. 
   '''
@@ -72,20 +73,10 @@ class MainWindow(Tools):
 
     # Start hotkey manager
     self.hotkey_manager = HotkeyManager()
-    self.hotkey_manager.addKeyCombo('Core',_('Core'),
-                                    N_('Inspect last focused accessible'),
-                                    self._inspectLastFocused, 
-                                    gtk.keysyms.a,
-                                    gtk.gdk.CONTROL_MASK | gtk.gdk.MOD1_MASK)
-    self.hotkey_manager.addKeyCombo('Core',_('Core'),
-                                    N_('Inspect accessible under mouse'),
-                                    self._inspectUnderMouse, 
-                                    gtk.keysyms.question,
-                                    gtk.gdk.CONTROL_MASK | gtk.gdk.MOD1_MASK)
 
     self.node.connect('accessible_changed', self._onAccesibleChange)
 
-    self.bookmarks_store = BookmarkStore(self.node, self.window.uimanager)
+    self.bookmarks_store = BookmarkStore(self.node)
 
     # load plugins
     self.plugin_manager = \
@@ -95,24 +86,27 @@ class MainWindow(Tools):
     # connect signal handlers and show the GUI in its initial state
     self.window.show_all()
 
-    pyatspi.Registry.registerEventListener(self._accEventFocusChanged, 
-                                           'focus')
+    main_actions = gtk.ActionGroup('MainActions')
+    ui_manager.uimanager.insert_action_group(main_actions, 0)
+    main_actions.add_actions([
+        ('Quit', gtk.STOCK_QUIT, None, 
+         '<control>q', 'Quit Accerciser', self._onQuit),
+        ('Preferences', gtk.STOCK_PREFERENCES, _('_Preferences...'),
+         '<control>p', 'Show preferences', self._onShowPreferences),
+        ('Contents', gtk.STOCK_HELP, _('_Contents'),
+         'F1', 'View contents of manual', self._onHelp),
+        ('About', gtk.STOCK_ABOUT, None,
+         None, 'About Accerciser', self._onAbout)])
 
-    masks = []
-    mask = 0
-    while mask <= (1 << pyatspi.MODIFIER_NUMLOCK):
-      masks.append(mask)
-      mask += 1
-    pyatspi.Registry.registerKeystrokeListener(self._accEventKeyPressed,
-                                               mask=masks,
-                                               kind=(pyatspi.KEY_PRESSED_EVENT,))
+    for action_name, menu_path in [('Quit', ui_manager.FILE_MENU_PATH),
+                                  ('Preferences', ui_manager.EDIT_MENU_PATH),
+                                  ('Contents', ui_manager.HELP_MENU_PATH),
+                                  ('About', ui_manager.HELP_MENU_PATH)]:
+      action = main_actions.get_action(action_name)
+      ui_manager.uimanager.add_ui(ui_manager.uimanager.new_merge_id(), 
+                                  menu_path, action_name, action_name, 
+                                  gtk.UI_MANAGER_MENUITEM, False)
 
-    for action_name, callback in [('Quit', self._onQuit),
-                                  ('Preferences', self._onShowPreferences),
-                                  ('Contents', self._onHelp),
-                                  ('About', self._onAbout)]:
-      action = self.window.main_actions.get_action(action_name)
-      action.connect('activate', callback)
 
     self.last_focused = None
     self.window.show_all()
@@ -214,95 +208,6 @@ class MainWindow(Tools):
     '''
     gnome.help_display('accerciser.xml')
          
-  def _accEventFocusChanged(self, event):
-    '''
-    Hold a reference for the last focused accessible. This is used when a certain 
-    global hotkey is pressed to select this accessible.
-
-    @param event: The event that is being handled.
-    @type event: L{pyatspi.event.Event}
-    '''
-    if not self.isMyApp(event.source):
-      self.last_focused = event.source
-
-  def _inspectLastFocused(self):
-    '''
-    Inspect the last focused widget's accessible.
-    '''
-    if self.last_focused:
-      self.node.update(self.last_focused)
-      
-  def _inspectUnderMouse(self):
-    '''
-    Inspect accessible of widget under mouse.
-    '''
-    # Inspect accessible under mouse
-    display = gtk.gdk.Display(gtk.gdk.get_display())
-    screen, x, y, flags =  display.get_pointer()
-    desktop = pyatspi.Registry.getDesktop(0)
-    wnck_screen = wnck.screen_get_default()
-    window_order = [w.get_name() for w in wnck_screen.get_windows_stacked()]
-    top_window = (None, -1)
-    for app in desktop:
-      if not app or self.isMyApp(app):
-        continue
-      for frame in app:
-        if not frame:
-          continue
-        acc = self._getChildAccAtCoords(frame, x, y)
-        if acc:
-          try:
-            z_order = window_order.index(frame.name)
-          except ValueError:
-            continue
-          if z_order > top_window[1]:
-            top_window = (acc, z_order)
-    if top_window[0]:
-      self.node.update(top_window[0])
-
-  def _accEventKeyPressed(self, event):
-    '''
-    Handle certain key presses globally. Pass on to the hotkey manager the 
-    key combinations pressed for further processing.
-    
-    @param event: The event that is being handled.
-    @type event: L{pyatspi.event.Event}
-    '''
-    handled = self.hotkey_manager.hotkeyPress(event.hw_code, event.modifiers)
-    event.consume = handled
-
-  def _getChildAccAtCoords(self, parent, x, y):
-    '''
-    Gets any child accessible that resides under given desktop coordinates.
-
-    @param parent: Top-level accessible.
-    @type parent: L{Accessibility.Accessible}
-    @param x: X coordinate.
-    @type x: integer
-    @param y: Y coordinate.
-    @type y: integer
-
-    @return: Child accessible at given coordinates, or None.
-    @rtype: L{Accessibility.Accessible}
-    '''
-    container = parent
-    while True:
-      try:
-        ci = container.queryComponent()
-      except:
-        return None
-      else:
-        inner_container = container
-      container =  ci.getAccessibleAtPoint(x, y, pyatspi.DESKTOP_COORDS)
-      if not container or container.queryComponent() == ci:
-        # The gecko bridge simply has getAccessibleAtPoint return itself
-        # if there are no further children
-        break
-    if inner_container == parent:
-      return None
-    else:
-      return inner_container
-
   def _onShowPreferences(self, action):
     '''
     Shows the preferences dialog.
